/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DirectoryManagerBean.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.mavenplugin.examples.directory;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.ejb.Local;
import javax.ejb.Stateful;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

/**
 * Directory manager bean implementation.
 * @author Julien Blais
 */
@Stateful(mappedName = "ejb/DirectoryManagerBean")
@Local(DirectoryManagerLocal.class)
public class DirectoryManagerBean implements DirectoryManagerLocal {

    /**
     * Entity manager used by this bean.
     */
    @PersistenceContext(unitName = "entity")
    private EntityManager em = null;

    /**
     * Directory uses by this bean.
     */
    private Directorys dir = null;

    public Directorys getDir() {
        return dir;
    }

    public void setDir(final Directorys dir) {
        this.dir = dir;
    }

    public void add(final String firstName, final String lastName, final String adress, final String phone) {
        /* Existence test*/
        Boolean insert = true;
        EltDirOf elt;
        Person p;
        List<EltDirOf> rl = em.createNamedQuery("EltDirOf.findByIdDirectory")
                .setParameter("iddirectory", dir).getResultList();

        if (!rl.isEmpty()) {
            for (EltDirOf eltDir : rl) {
                if (eltDir.getIdperson().getFirstname().equals(firstName)) {
                    insert = false;
                    break;
                }
            }
        }
        if (insert) {
            p = new Person(firstName, phone);
            if (lastName.length() != 0) {
                p.setLastname(lastName);
            }
            if (adress.length() != 0) {
                p.setAdress(adress);
            }
            em.persist(p);
            em.flush();
            elt = new EltDirOf();
            elt.setIddirectory(dir);
            elt.setIdperson(p);
            em.persist(elt);
            em.flush();

            System.out.println("Insert person " + firstName + " " + lastName);
        }
    }

    public void remove(final String firstName, final String phone) {
        boolean removed = false;
        EltDirOf elt;
        List<EltDirOf> rl = em.createNamedQuery("EltDirOf.findByIdDirectory")
                .setParameter("iddirectory", dir).getResultList();
        Iterator<EltDirOf> itElt = rl.iterator();
        if (!rl.isEmpty()) {
            while (!removed && itElt.hasNext()) {
                elt = itElt.next();
                if (elt.getIdperson().getFirstname().equals(firstName)
                        && elt.getIdperson().getPhone().equals(phone)) {
                    em.remove(elt);
                    removed = true;
                }
            }
        }
    }

    public String getPhoneNumber(final String firstName, final String lastName) throws Exception {
        EltDirOf elt;
        String phone = null;
        Iterator<EltDirOf> itElt;

        System.out.println("Call getPhoneNumber method...");

        List<EltDirOf> rl = em.createNamedQuery("EltDirOf.findByIdDirectory")
                .setParameter("iddirectory", dir).getResultList();
        boolean found = false;
        if (firstName.length() != 0) {
            itElt = rl.iterator();
            while (!found && itElt.hasNext()) {

                elt = (EltDirOf) itElt.next();
                if (elt.getIdperson().getFirstname().equals(firstName)) {
                    if (lastName.length() != 0
                       && elt.getIdperson().getLastname().equals(lastName)) {
                        phone = elt.getIdperson().getPhone();
                        found = true;
                    }
                    found = true;
                    phone = elt.getIdperson().getPhone();
                }
            }
        }
        if (!found) {
            throw new Exception("Person " + firstName + " " + lastName + " not found");
        }
        return phone;
    }

    public ArrayList getList() {
        ArrayList<Person> lPers = new ArrayList<Person>();
        List<EltDirOf> lElt = em.createNamedQuery("EltDirOf.findByIdDirectory")
                .setParameter("iddirectory", dir).getResultList();

        for (EltDirOf elt : lElt) {
            lPers.add(elt.getIdperson());
        }

        return lPers;
    }

    public List<Sessions> getListSessions() {
        return em.createNamedQuery("Sessions.findAll").getResultList();
    }

    public void addNewSession(final Sessions s) {
        em.persist(s);
        em.flush();
    }

    public void addNewDirectory(final Directorys dir) {
        em.persist(dir);
        em.flush();
    }

    public List<Directorys> getListDir() {
        return em.createNamedQuery("Directorys.findAll").getResultList();
    }
}
