/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EltDirOf.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.mavenplugin.examples.directory;

import java.io.Serializable;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;

/**
 * Entity bean for table EltDirOf.
 * @author Julien Blais
 */
@Entity
@Table(name = "ELTDIROF")
@NamedQueries({
@NamedQuery(name = "EltDirOf.findAll", query = "SELECT e FROM EltDirOf e"),
@NamedQuery(name = "EltDirOf.findByIdelt", query = "SELECT e FROM EltDirOf e WHERE e.idelt = :idelt"),
@NamedQuery(name = "EltDirOf.findByIdDirectory", query = "SELECT e FROM EltDirOf e WHERE e.iddirectory = :iddirectory")})
public class EltDirOf implements Serializable {
    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = 287794697084069L;

    /**
     * Auto generated id of this instance.
     */
    @Id
    @Basic(optional = false)
    @Column(name = "IDELT")
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Integer idelt;

    /**
     * The directory id.
     */
    @JoinColumn(name = "IDDIRECTORY", referencedColumnName = "IDDIRECTORY")
    @ManyToOne(optional = false, fetch = FetchType.EAGER)
    private Directorys iddirectory;

    /**
     * The person id.
     */
    @JoinColumn(name = "IDPERSON", referencedColumnName = "IDPERS")
    @ManyToOne(optional = false, fetch = FetchType.EAGER)
    private Person idperson;

    /**
     * Empty constructor.
     */
    public EltDirOf() {
    }

    /**
     * Gets the id of this instance.
     * @return the id
     */
    public Integer getIdelt() {
        return idelt;
    }

    /**
     * Get the id of the referenced directory.
     * @return the id of the directory
     */
    public Directorys getIddirectory() {
        return iddirectory;
    }

    /**
     * Set the id of the referenced directory.
     * @param iddirectory the new directory referenced by this instance
     */
    public void setIddirectory(final Directorys iddirectory) {
        this.iddirectory = iddirectory;
    }

    /**
     * Get the referenced person id.
     * @return the person id
     */
    public Person getIdperson() {
        return idperson;
    }

    /**
     * Set the referenced person id.
     * @param idperson the new referenced person id
     */
    public void setIdperson(final Person idperson) {
        this.idperson = idperson;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        if (idelt != null) {
            hash += idelt.hashCode();
        } else {
            hash += 0;
        }
        return hash;
    }

    @Override
    public boolean equals(final Object object) {

        if (!(object instanceof EltDirOf)) {
            return false;
        }
        EltDirOf other = (EltDirOf) object;
        if ((this.idelt == null && other.idelt != null) || (this.idelt != null && !this.idelt.equals(other.idelt))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "EltDirOf[idelt=" + idelt + "]";
    }

}
